@@ -25,8 +25,8 @@ read_pertAOA <- function(yourdata, pert_param){
 
   create_edge_df(from = as.integer(yourdata[,1]), to = as.integer(yourdata[,2]),
                    label = as.character(yourdata[,3]),
-                   time = PERT_mu(pert_param, yourdata[,4], yourdata[,5], yourdata[,6]),
-                   timevar = PERT_var(pert_param, yourdata[,4], yourdata[,5], yourdata[,6]),
+                   time = round(PERT_mu(pert_param, yourdata[,4], yourdata[,5], yourdata[,6]), 4),
+                   timevar = round(PERT_var(pert_param, yourdata[,4], yourdata[,5], yourdata[,6]), 4),
                    TF = rep(0, nrow(yourdata)),)
 }
 #===============================================================================
@@ -159,7 +159,7 @@ scheduleAOA <- function(relations, deterministic){
   # Completes the rest of the schedule.
   yourschedule$LSij <- yourschedule$LFij - yourschedule$Duration
   yourschedule$EFij <- yourschedule$ESij + yourschedule$Duration
-  yourschedule$TFij <- yourschedule$LFij - yourschedule$ESij - yourschedule$Duration
+  yourschedule$TFij <- round(yourschedule$LFij - yourschedule$ESij - yourschedule$Duration, 4)
   yourschedule$Crit[which(yourschedule$TFij == 0)] <- c("*")
 
   # Completes TF for the edges data frame.
